# -*- coding: utf-8 -*-
# @Time    : 2018-12-14 17:55
# @Author  : play4fun
# @File    : DdkWeappQrcodeUrlGen.py
# @Software: PyCharm

"""
DdkWeappQrcodeUrlGen.py:

http://open.pinduoduo.com/#/apidocument/port?id=106
多多客生成单品推广小程序二维码url
"""


from ddk.api.base import RestApi


class DdkWeappQrcodeUrlGen(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.p_id = None  # 推广位id
        self.goods_id_list = None  # 商品ID，仅支持单个查询
        self.custom_parameters = None  # 自定义参数
        self.zs_duo_id = None  # 招商多多客ID

    def getapiname(self):
        return 'pdd.ddk.weapp.qrcode.url.gen'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 14:02
# @Author  : play4fun
# @File    : DdkGoodsSearch.py
# @Software: PyCharm

"""
DdkGoodsSearch.py:

https://open.pinduoduo.com/#/apidocument/port?id=27
多多进宝商品查询
"""

from ddk.api.base import RestApi


class DdkGoodsSearch(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.keyword = None  # 商品关键词，与opt_id字段选填一个或全部填写

        self.page_size = None  # 默认100，每页商品数量
        self.sort_type = None  # 排序方式:0-综合排序;1-按佣金比率升序;2-按佣金比例降序;3-按价格升序;4-按价格降序;5-按销量升序;6-按销量降序;7-优惠券金额排序升序;8-优惠券金额排序降序;9-券后价升序排序;10-券后价降序排序;11-按照加入多多进宝时间升序;12-按照加入多多进宝时间降序;13-按佣金金额升序排序;14-按佣金金额降序排序;15-店铺描述评分升序;16-店铺描述评分降序;17-店铺物流评分升序;18-店铺物流评分降序;19-店铺服务评分升序;20-店铺服务评分降序;27-描述评分击败同类店铺百分比升序，28-描述评分击败同类店铺百分比降序，29-物流评分击败同类店铺百分比升序，30-物流评分击败同类店铺百分比降序，31-服务评分击败同类店铺百分比升序，32-服务评分击败同类店铺百分比降序
        self.with_coupon = None  # false返回所有商品，true只返回有优惠券的商品
        self.range_list = None  #
        self.cat_id = None  # 商品类目ID，使用pdd.goods.cats.get接口获取
        self.goods_id_list = None  # 商品ID列表。例如：[123456,123]，当入参带有goods_id_list字段，将不会以opt_id、 cat_id、keyword维度筛选商品
        self.zs_duo_id = None  # 招商多多客ID
        self.merchant_type = None  # 店铺类型，1-个人，2-企业，3-旗舰店，4-专卖店，5-专营店，6-普通店（未传为全部）
        self.pid = None  # 推广位id
        self.custom_parameters = None  # 自定义参数

    def getapiname(self):
        return 'pdd.ddk.goods.search'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-10 15:27
# @Author  : play4fun
# @File    : DdkGoodsPidGenerate.py
# @Software: PyCharm

"""
DdkGoodsPidGenerate.py:

创建多多进宝推广位
"""

from ddk.api.base import RestApi


class DdkGoodsPidGenerate(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.number = None  # 要生成的推广位数量，默认为10，范围为：1~100
        self.p_id_name_list = None  # 推广位名称，例如["1","2"]

    def getapiname(self):
        return 'pdd.ddk.goods.pid.generate'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 16:34
# @Author  : play4fun
# @File    : DdkMallUrlGen.py
# @Software: PyCharm

"""
DdkMallUrlGen.py:
http://open.pinduoduo.com/#/apidocument/port?id=179

多多客工具生成店铺推广链接API
"""

from ddk.api.base import RestApi


class DdkMallUrlGen(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        #
        self.mall_id = None  # 店铺id
        self.pid = None  # 推广位
        self.generate_weapp_webview = None  # 是否生成唤起微信客户端链接，true-是，false-否，默认false
        self.generate_short_url = None  # 是否生成短链接，true-是，false-否
        self.multi_group = None  # true--生成多人团推广链接 false--生成单人团推广链接（默认false）1、单人团推广链接：用户访问单人团推广链接，可直接购买商品无需拼团。2、多人团推广链接：用户访问双人团推广链接开团，若用户分享给他人参团，则开团者和参团者的佣金均结算给推手
        self.custom_parameters = None  # 自定义参数，为链接打上自定义标签。自定义参数最长限制64个字节。

    def getapiname(self):
        return 'pdd.ddk.mall.url.gen'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 11:50
# @Author  : play4fun
# @File    : base.py
# @Software: PyCharm

"""
base.py:
"""

try:
    import httplib
except ImportError:
    import http.client as httplib
import urllib
import time
import hashlib
import json
import ddk
import itertools
import mimetypes

'''
定义一些系统变量
'''

SYSTEM_GENERATE_VERSION = "ddk-sdk-python-20181209"

P_APPKEY = "client_id"
P_API = "type"
P_SESSION = "session"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "version"
P_FORMAT = "data_type"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_SIGN_METHOD = "sign_method"
P_PARTNER_ID = "partner_id"

P_CODE = 'code'
P_SUB_CODE = 'sub_code'
P_MSG = 'msg'
P_SUB_MSG = 'sub_msg'

N_REST = '/api/router'


def sign(secret, parameters):
    # ===========================================================================
    # '''签名方法
    # @param secret: 签名需要的密钥
    # @param parameters: 支持字典和string两种
    # '''
    # ===========================================================================
    # 如果parameters 是字典类的话
    if hasattr(parameters, "items"):
        keys = parameters.keys()
        # keys.sort()
        keys = sorted(keys)

        parameters = "%s%s%s" % (secret,
                                 str().join('%s%s' % (key, parameters[key]) for key in keys),
                                 secret)
    sign = hashlib.md5(parameters.encode('utf-8')).hexdigest().upper()
    return sign


def mixStr(pstr):
    if (isinstance(pstr, str)):
        return pstr
    # elif(isinstance(pstr, unicode)):
    elif (isinstance(pstr, bytes)):
        # return pstr.encode('utf-8')
        return pstr.decode('utf-8')
    else:
        return str(pstr)


class FileItem(object):
    def __init__(self, filename=None, content=None):
        self.filename = filename
        self.content = content


class MultiPartForm(object):
    """Accumulate the data to be used when posting a form."""

    def __init__(self):
        self.form_fields = []
        self.files = []
        self.boundary = "PYTHON_SDK_BOUNDARY"
        return

    def get_content_type(self):
        return 'multipart/form-data; boundary=%s' % self.boundary

    def add_field(self, name, value):
        """Add a simple field to the form data."""
        self.form_fields.append((name, str(value)))
        return

    def add_file(self, fieldname, filename, fileHandle, mimetype=None):
        """Add a file to be uploaded."""
        body = fileHandle.read()
        if mimetype is None:
            mimetype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
        self.files.append((mixStr(fieldname), mixStr(filename), mixStr(mimetype), mixStr(body)))
        return

    def __str__(self):
        """Return a string representing the form data, including attached files."""
        # Build a list of lists, each containing "lines" of the
        # request.  Each part is separated by a boundary string.
        # Once the list is built, return a string where each
        # line is separated by '\r\n'.
        parts = []
        part_boundary = '--' + self.boundary

        # Add the form fields
        parts.extend(
            [part_boundary,
             'Content-Disposition: form-data; name="%s"' % name,
             'Content-Type: text/plain; charset=UTF-8',
             '',
             value,
             ]
            for name, value in self.form_fields
        )

        # Add the files to upload
        parts.extend(
            [part_boundary,
             'Content-Disposition: file; name="%s"; filename="%s"' % \
             (field_name, filename),
             'Content-Type: %s' % content_type,
             'Content-Transfer-Encoding: binary',
             '',
             body,
             ]
            for field_name, filename, content_type, body in self.files
        )

        # Flatten the list and add closing boundary marker,
        # then return CR+LF separated data
        flattened = list(itertools.chain(*parts))
        flattened.append('--' + self.boundary + '--')
        flattened.append('')
        return '\r\n'.join(flattened)


class DdkException(Exception):
    # ===========================================================================
    # 业务异常类
    # ===========================================================================
    def __init__(self):
        self.errorcode = None
        self.message = None
        self.subcode = None
        self.submsg = None
        self.application_host = None
        self.service_host = None

    def __str__(self, *args, **kwargs):
        sb = "errorcode=" + mixStr(self.errorcode) + \
             " message=" + mixStr(self.message) + \
             " subcode=" + mixStr(self.subcode) + \
             " submsg=" + mixStr(self.submsg) + \
             " application_host=" + mixStr(self.application_host) + \
             " service_host=" + mixStr(self.service_host)
        return sb


class RequestException(Exception):
    # ===========================================================================
    # 请求连接异常类
    # ===========================================================================
    pass


class RestApi(object):
    # ===========================================================================
    # Rest api的基类
    # ===========================================================================

    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        # =======================================================================
        # 初始化基类
        # Args @param domain: 请求的域名或者ip
        #      @param port: 请求的端口
        # =======================================================================
        self.__domain = domain
        self.__port = port
        self.__httpmethod = "POST"
        if (ddk.getDefaultAppInfo()):
            self.__app_key = ddk.getDefaultAppInfo().appkey
            self.__secret = ddk.getDefaultAppInfo().secret

    def get_request_header(self):
        return {
            'Content-type': 'application/x-www-form-urlencoded;charset=UTF-8',
            "Cache-Control": "no-cache",
            "Connection": "Keep-Alive",
        }

    def set_app_info(self, appinfo):
        # =======================================================================
        # 设置请求的app信息
        # @param appinfo: import ddk
        #                 appinfo ddk.appinfo(appkey,secret)
        # =======================================================================
        self.__app_key = appinfo.appkey
        self.__secret = appinfo.secret

    def getapiname(self):
        return ""

    def getMultipartParas(self):
        return [];

    def getTranslateParas(self):
        return {};

    def _check_requst(self):
        pass

    def getResponse(self, authrize=None, timeout=30):
        # =======================================================================
        # 获取response结果
        # =======================================================================
        connection = httplib.HTTPConnection(self.__domain, self.__port, timeout)
        # sys_parameters = {
        #     P_FORMAT: 'json',
        #     P_APPKEY: self.__app_key,
        #     P_SIGN_METHOD: "md5",
        #     P_VERSION: '2.0',
        #     P_TIMESTAMP: str(int(time.time())),
        #     P_PARTNER_ID: SYSTEM_GENERATE_VERSION,
        #     P_API: self.getapiname(),
        # }
        sys_parameters = {
            P_FORMAT: 'JSON',
            P_APPKEY: self.__app_key,
            # P_SIGN_METHOD: "md5",
            P_VERSION: 'V1',
            P_TIMESTAMP: str(int(time.time())),#UNIX时间戳，单位秒，需要与拼多多服务器时间差值在10分钟内
            # P_PARTNER_ID: SYSTEM_GENERATE_VERSION,
            P_API: self.getapiname(),
        }

        if authrize is not None:
            sys_parameters[P_SESSION] = authrize
        application_parameter = self.getApplicationParameters()
        sign_parameter = sys_parameters.copy()
        sign_parameter.update(application_parameter)
        #
        sys_parameters[P_SIGN] = sign(self.__secret, sign_parameter)
        connection.connect()

        header = self.get_request_header()
        if (self.getMultipartParas()):
            form = MultiPartForm()
            for key, value in application_parameter.items():
                form.add_field(key, value)
            for key in self.getMultipartParas():
                fileitem = getattr(self, key)
                if (fileitem and isinstance(fileitem, FileItem)):
                    form.add_file(key, fileitem.filename, fileitem.content)
            body = str(form)
            header['Content-type'] = form.get_content_type()
        else:
            body = urllib.parse.urlencode(application_parameter)

        url = N_REST + "?" + urllib.parse.urlencode(sys_parameters)
        connection.request(self.__httpmethod, url, body=body, headers=header)
        response = connection.getresponse()
        # print(body,url)#验证

        if response.status is not 200:
            raise RequestException('invalid http status ' + str(response.status) + ',detail body:' + response.read())
        result = response.read()
        jsonobj = json.loads(result)
        # print(jsonobj)#测试

        # if jsonobj.has_key("error_response"):
        if "error_response" in jsonobj:
            error = DdkException()
            # if jsonobj["error_response"].has_key(P_CODE) :
            if P_CODE in jsonobj["error_response"]:
                error.errorcode = jsonobj["error_response"][P_CODE]
            # if jsonobj["error_response"].has_key(P_MSG) :
            if P_MSG in jsonobj["error_response"]:
                error.message = jsonobj["error_response"][P_MSG]
            # if jsonobj["error_response"].has_key(P_SUB_CODE) :
            if P_SUB_CODE in jsonobj["error_response"]:
                error.subcode = jsonobj["error_response"][P_SUB_CODE]
            # if jsonobj["error_response"].has_key(P_SUB_MSG) :
            if P_SUB_MSG in jsonobj["error_response"]:
                error.submsg = jsonobj["error_response"][P_SUB_MSG]

            error.application_host = response.getheader("Application-Host", "")
            error.service_host = response.getheader("Location-Host", "")
            raise error
        return jsonobj

    def getApplicationParameters(self):
        application_parameter = {}
        for key, value in self.__dict__.items():
            if not key.startswith("__") and not key in self.getMultipartParas() and not key.startswith("_RestApi__") and value is not None:
                if (key.startswith("_")):
                    application_parameter[key[1:]] = value
                else:
                    application_parameter[key] = value
        # 查询翻译字典来规避一些关键字属性
        translate_parameter = self.getTranslateParas()
        for key, value in application_parameter.items():
            if key in translate_parameter:
                application_parameter[translate_parameter[key]] = application_parameter[key]
                del application_parameter[key]
        return application_parameter



# -*- coding: utf-8 -*-
# @Time    : 2018-12-10 15:40
# @Author  : play4fun
# @File    : DdkRpPromUrlGenerate.py
# @Software: PyCharm

"""
DdkRpPromUrlGenerate.py:
生成红包推广链接
"""

from ddk.api.base import RestApi


class DdkRpPromUrlGenerate(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.generate_short_url = None  # 是否生成短链接，true-是，false-否
        self.p_id_list = None  # 推广位列表，例如：["60005_612"]
        self.custom_parameters = None  # 自定义参数，为链接打上自定义标签。自定义参数最长限制64个字节。
        self.generate_weapp_webview = None  # 是否生成唤起微信客户端链接，true-是，false-否，默认false
        self.we_app_web_view_short_url = None  # 唤起微信app推广短链接
        self.we_app_web_wiew_url = None  # 唤起微信app推广链接
        self.generate_we_app: bool = None  # 是否生成小程序推广

    def getapiname(self):
        return 'pdd.ddk.rp.prom.url.generate'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 14:47
# @Author  : play4fun
# @File    : DdkGoodsPidQuery.py
# @Software: PyCharm

"""
DdkGoodsPidQuery.py:
查询已经生成的推广位信息
"""

from ddk.api.base import RestApi


class DdkGoodsPidQuery(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.page_size = None  # 返回的每页推广位数量
        self.page = None  #

    def getapiname(self):
        return 'pdd.ddk.goods.pid.query'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 16:17
# @Author  : play4fun
# @File    : DdkMerchantListGet.py
# @Software: PyCharm

"""
DdkMerchantListGet.py:
http://open.pinduoduo.com/#/apidocument/port?id=179

多多客查店铺列表接口
"""

from ddk.api.base import RestApi


class DdkMerchantListGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        #
        self.mall_id_list = None  # 店铺id
        self.merchant_type_list = None  # 店铺类型
        self.query_range_str = None  # 查询范围0----商品拼团价格区间；1----商品券后价价格区间；2----佣金比例区间；3----优惠券金额区间；4----加入多多进宝时间区间；5----销量区间；6----佣金金额区间
        self.cat_id = None  # 商品类目ID，使用pdd.goods.cats.get接口获取
        self.has_coupon = None  # 是否有优惠券 （0 所有；1 必须有券。）
        self.page_number = None  # 分页数
        self.page_size = None  # 每页数量
        self.range_vo_list = None  # 筛选范围

    def getapiname(self):
        return 'pdd.ddk.merchant.list.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 11:50
# @Author  : play4fun
# @File    : __init__.py.py
# @Software: PyCharm

"""
__init__.py.py:
"""

from ddk.api.rest import *
from ddk.api.base import FileItem


# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 14:56
# @Author  : play4fun
# @File    : DdkOrderListIncrementGet.py
# @Software: PyCharm

"""
DdkOrderListIncrementGet.py:

最后更新时间段增量同步推广订单信息

按照时间段获取授权多多客下面所有多多客的推广订单信息
"""

from ddk.api.base import RestApi


class DdkOrderListIncrementGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)

        self.start_update_time: int = None  # 最近90天内多多进宝商品订单更新时间--查询时间开始。note：此时间为时间戳，指格林威治时间 1970 年01 月 01 日 00 时 00 分 00 秒(北京时间 1970 年 01 月 01 日 08 时
        # 00 分 00 秒)起至现在的总秒数
        self.end_update_time: int = None  # 查询结束时间，和开始时间相差不能超过24小时。note：此时间为时间戳，指格林威治时间 1970 年01 月 01 日 00 时 00 分 00 秒(北京时间 1970 年 01 月 01 日 08 时 00 分 00 秒)起至现在的总秒数
        self.page_size = None  # 返回的每页结果订单数，默认为100，范围为10到100，建议使用40~50，可以提高成功率，减少超时数量。
        self.page = None  # 第几页，从1到10000，默认1，注：使用最后更新时间范围增量同步时，必须采用倒序的分页方式（从最后一页往回取）才能避免漏单问题。
        self.return_count = None  # 是否返回总数，默认为true，如果指定false, 则返回的结果中不包含总记录数，通过此种方式获取增量数据，效率在原有的基础上有80%的提升。

    def getapiname(self):
        return 'pdd.ddk.order.list.increment.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 16:54
# @Author  : play4fun
# @File    : DdkMallGoodsListGet.py
# @Software: PyCharm

"""
DdkMallGoodsListGet.py:
http://open.pinduoduo.com/#/apidocument/port?id=179

查询店铺商品
"""

from ddk.api.base import RestApi


class DdkMallGoodsListGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.mall_id = None  # 店铺id
        self.page_number = None  # 分页数
        self.page_size = None  # 返回的每页推广位数量

    def getapiname(self):
        return 'pdd.ddk.mall.goods.list.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 17:05
# @Author  : play4fun
# @File    : DdkThemeListGet.py
# @Software: PyCharm

"""
DdkThemeListGet.py:
http://open.pinduoduo.com/#/apidocument/port?id=179

查询多多进宝主题列表
"""

from ddk.api.base import RestApi


class DdkThemeListGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        #
        self.page_size = None  #
        self.page = None  #

    def getapiname(self):
        return 'pdd.ddk.theme.list.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-10 15:12
# @Author  : play4fun
# @File    : DdkOrderDetailGet.py
# @Software: PyCharm

"""
DdkOrderDetailGet.py:
查询订单详情

"""

from ddk.api.base import RestApi


class DdkOrderDetailGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.order_sn = None  # 订单号

    def getapiname(self):
        return 'pdd.ddk.order.detail.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 16:03
# @Author  : play4fun
# @File    : GoodsCatsGet.py
# @Software: PyCharm

"""
GoodsCatsGet.py:
http://open.pinduoduo.com/#/apidocument/port?id=17

获取拼多多标准商品类目信息（请使用pdd.goods.authorization.cats接口获取商家可发布类目）
"""

from ddk.api.base import RestApi


class GoodsCatsGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        #
        self.parent_cat_id = None  # 值=0时为顶点cat_id,通过树顶级节点获取cat树

    def getapiname(self):
        return 'pdd.goods.cats.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-14 17:36
# @Author  : play4fun
# @File    : DdkGoodsZsUnitUrlGen.py
# @Software: PyCharm

"""
DdkGoodsZsUnitUrlGen.py:
http://open.pinduoduo.com/#/apidocument/port?id=106
多多进宝转链接口

本功能适用于采集群等场景。将其他推广者的推广链接转换成自己的；
通过此api，可以将他人的招商推广链接，转换成自己的招商推广链接
"""

from ddk.api.base import RestApi


class DdkGoodsZsUnitUrlGen(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.source_url = None  # 需转链的链接
        self.pid: int = None  # 推广位id

    def getapiname(self):
        return 'pdd.ddk.goods.zs.unit.url.gen'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 11:47
# @Author  : play4fun
# @File    : __init__.py.py
# @Software: PyCharm

"""
__init__.py.py:
"""

__version__ = '19.1.14.18'
__author__ = 'play4fun <play4fun@foxmail.com>'

from ddk.api.base import sign


class appinfo(object):
    def __init__(self, appkey, secret):
        self.appkey = appkey
        self.secret = secret


def getDefaultAppInfo():
    pass


def setDefaultAppInfo(appkey, secret):
    default = appinfo(appkey, secret)
    global getDefaultAppInfo
    getDefaultAppInfo = lambda: default



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 12:55
# @Author  : play4fun
# @File    : DdkGoodsDetail.py
# @Software: PyCharm

"""
DdkGoodsDetail.py:

https://open.pinduoduo.com/#/apidocument/port?id=27

"""

from ddk.api.base import RestApi


class DdkGoodsDetail(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.goods_id_list = None  # 商品ID，仅支持单个查询。例如：[123456]
        self.pid = None  # 推广位id
        self.custom_parameters = None  # 自定义参数

    def getapiname(self):
        return 'pdd.ddk.goods.detail'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 11:42
# @Author  : play4fun
# @File    : setup.py
# @Software: PyCharm

"""
setup.py:
"""


from setuptools import setup, find_packages
# print('find_packages:',find_packages())

setup(
    name='ddk',
    version='19.1.14.18',  # 按日期
    author='play4fun',
    author_email='play4fun@foxmail.com',
    packages=find_packages(),
    install_requires=[],
    license='MIT',
    description="拼多多-多多客联盟 CPS 工具包",
    long_description_content_type="text/markdown",
    long_description='拼多多-多多客联盟 sdk,进行导购推广,有了它，不需要去写爬虫抓取联盟商品信息'
)



# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 17:09
# @Author  : play4fun
# @File    : DdkThemeGoodsSearch.py
# @Software: PyCharm

"""
DdkThemeGoodsSearch.py:
"""

from ddk.api.base import RestApi


class DdkThemeGoodsSearch(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        #
        self.theme_id = None  # 主题ID

    def getapiname(self):
        return 'pdd.ddk.theme.goods.search'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 14:27
# @Author  : play4fun
# @File    : DdkGoodsPromotionUrlGenerate.py
# @Software: PyCharm

"""
DdkGoodsPromotionUrlGenerate.py:
生成普通商品推广链接
"""

from ddk.api.base import RestApi


class DdkGoodsPromotionUrlGenerate(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.goods_id_list = None  # 商品ID，仅支持单个查询。例如：[123456]
        self.p_id: int = None  # 推广位id
        self.generate_short_url = None  # 是否生成短链接，true-是，false-否
        self.multi_group = None  # true--生成多人团推广链接 false--生成单人团推广链接（默认false）1、单人团推广链接：用户访问单人团推广链接，可直接购买商品无需拼团。2、多人团推广链接：用户访问双人团推广链接开团，若用户分享给他人参团，则开团者和参团者的佣金均结算给推手
        self.custom_parameters = None  # 自定义参数，为链接打上自定义标签。自定义参数最长限制64个字节。
        self.pull_new = None  # 是否开启订单拉新，true表示开启（订单拉新奖励特权仅支持白名单，请联系工作人员开通）
        self.generate_weapp_webview = None  # 是否生成唤起微信客户端链接，true-是，false-否，默认false
        self.zs_duo_id = None  # 招商多多客ID
        self.generate_we_app: bool = None  # 是否生成小程序推广

    def getapiname(self):
        return 'pdd.ddk.goods.promotion.url.generate'
